==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/messaggi.php <==
<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Retour au menu principal"; break;
case "Nuovo messaggio a":  			$messaggio = "Nouveau message pour"; break;
case "da mostrare dopo le":  			$messaggio = "montrer après"; break;
case "il":  					$messaggio = "le"; break;
case "testo del messaggio":  			$messaggio = "texte du message"; break;
case "Spedisci":  				$messaggio = "Envoyer"; break;
case "Messaggio inviato":  			$messaggio = "Message envoyé"; break;
case "Torna indietro":  			$messaggio = "Retour"; break;
case "N°":  					$messaggio = "N°"; break;
case "Mittente":  				$messaggio = "Expéditeur"; break;
case "Testo":  					$messaggio = "Texte"; break;
case "Elimina":  				$messaggio = "Supprimer"; break;
case "Messaggio eliminato":  			$messaggio = "Message supprimé"; break;
case "tutti":  					$messaggio = "tout le monde"; break;
case "SI":  					$messaggio = "OUI"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "Êtes-vous sûr de vouloir supprimer la demande de réservation de"; break;
case "non ancora inserita?":  			$messaggio = "pas encore inséré?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insérer la réservation"; break;
case "Visualizza il documento":  		$messaggio = "voir le document"; break;
case "Inserito":  				$messaggio = "Inséré"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Supprimer tous les messages"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":	$messaggio = "Êtes-vous sûr de vouloir supprimer <div style=\"display: inline; color: red;\"><b>tous les messages</b></div>"; break;
case "Messaggi eliminati":  			$messaggio = "Messages supprimés"; break;
case "arrivati":  				$messaggio = "arrivés"; break;
case "prima del":  				$messaggio = "avant le"; break;
case "dopo il":  				$messaggio = "après le"; break;
case "Messaggi":  				$messaggio = "Messages"; break;
case "Data":  					$messaggio = "Date"; break;
case "Azioni":  				$messaggio = "Actions"; break;
case "di tipo":  				$messaggio = "type"; break;
case "Scarica messaggi email":  		$messaggio = "Download email messages"; break;
case "Nessun nuovo messaggio":  		$messaggio = "No new message"; break;
case "Nuovi messaggi":  			$messaggio = "New messages"; break;
case "Scaricati":  				$messaggio = "Downloaded"; break;
case "Connessione al server":  			$messaggio = "The connection to server"; break;
case "non riuscita!":  				$messaggio = "was refused!"; break;
case "Controllare i dati immessi in \"configura e personalizza\"":	$messaggio = "Check data inserted in \"configure and customize\""; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Email":  					$messaggio = "Email"; break;
case "arrivo":  				$messaggio = "arrival"; break;
case "partenza":  				$messaggio = "departure"; break;
case "notti":  					$messaggio = "nights"; break;
case "persone":  				$messaggio = "people"; break;
case "individui":  				$messaggio = "persons"; break;
case "ospiti":  				$messaggio = "guests"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambini":  				$messaggio = "children"; break;
case "gruppo":  				$messaggio = "party"; break;
case "date":  					$messaggio = "dates"; break;
case "viaggiatori":  				$messaggio = "travelers"; break;
case "periodo":  				$messaggio = "period"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_3.0.8-1.tar.gz: fr/messaggi.php <==
<?php

switch ($messaggio) {

case "Torna al menù principale":  		$messaggio = "Retour au menu principal"; break;
case "Nuovo messaggio a":  			$messaggio = "Nouveau message pour"; break;
case "da mostrare dopo le":  			$messaggio = "montrer après"; break;
case "il":  					$messaggio = "le"; break;
case "testo del messaggio":  			$messaggio = "texte du message"; break;
case "Spedisci":  				$messaggio = "Envoyer"; break;
case "Messaggio inviato":  			$messaggio = "Message envoyé"; break;
case "Torna indietro":  			$messaggio = "Retour"; break;
case "N°":  					$messaggio = "N°"; break;
case "Mittente":  				$messaggio = "Expéditeur"; break;
case "Testo":  					$messaggio = "Texte"; break;
case "Elimina":  				$messaggio = "Supprimer"; break;
case "Messaggio eliminato":  			$messaggio = "Message supprimé"; break;
case "tutti":  					$messaggio = "tout le monde"; break;
case "SI":  					$messaggio = "OUI"; break;
case "Si è sicuri di voler eliminare la richiesta di prenotazione di":	$messaggio = "Êtes-vous sûr de vouloir supprimer la demande de réservation de"; break;
case "non ancora inserita?":  			$messaggio = "pas encore inséré?"; break;
case "Inserisci la prenotazione":  		$messaggio = "Insérer la réservation"; break;
case "Visualizza il documento":  		$messaggio = "voir le document"; break;
case "Inserito":  				$messaggio = "Inséré"; break;
case "Elimina tutti i messaggi":  		$messaggio = "Supprimer tous les messages"; break;
case "Si è sicuri di voler eliminare <div style=\"display: inline; color: red;\"><b>tutti i messaggi</b></div>":	$messaggio = "Êtes-vous sûr de vouloir supprimer <div style=\"display: inline; color: red;\"><b>tous les messages</b></div>"; break;
case "Messaggi eliminati":  			$messaggio = "Messages supprimés"; break;
case "arrivati":  				$messaggio = "arrivés"; break;
case "prima del":  				$messaggio = "avant le"; break;
case "dopo il":  				$messaggio = "après le"; break;
case "Messaggi":  				$messaggio = "Messages"; break;
case "Data":  					$messaggio = "Date"; break;
case "Azioni":  				$messaggio = "Actions"; break;
case "di tipo":  				$messaggio = "type"; break;
case "Scarica messaggi email":  		$messaggio = "Download email messages"; break;
case "Nessun nuovo messaggio":  		$messaggio = "No new message"; break;
case "Nuovi messaggi":  			$messaggio = "New messages"; break;
case "Scaricati":  				$messaggio = "Downloaded"; break;
case "Connessione al server":  			$messaggio = "The connection to server"; break;
case "non riuscita!":  				$messaggio = "was refused!"; break;
case "Controllare i dati immessi in":  		$messaggio = "Check data inserted in"; break;
case "configura e personalizza":  		$messaggio = "configure and customize"; break;
case "Dati ricavati dal messaggio email":  	$messaggio = "Data extracted from email message"; break;
case "Controlla disponibilità":  		$messaggio = "Check availability"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "Nome":  					$messaggio = "Name"; break;
case "Email":  					$messaggio = "Email"; break;
case "arrivo":  				$messaggio = "arrival"; break;
case "partenza":  				$messaggio = "departure"; break;
case "notti":  					$messaggio = "nights"; break;
case "persone":  				$messaggio = "people"; break;
case "individui":  				$messaggio = "persons"; break;
case "ospiti":  				$messaggio = "guests"; break;
case "adulti":  				$messaggio = "adults"; break;
case "bambini":  				$messaggio = "children"; break;
case "gruppo":  				$messaggio = "party"; break;
case "date":  					$messaggio = "dates"; break;
case "viaggiatori":  				$messaggio = "travelers"; break;
case "periodo":  				$messaggio = "period"; break;
case "Per gli account su gmail potrebbe essere necessario abilitare l'opzione":	$messaggio = "For gmail accounts you may have to enable the option"; break;
case "e/o per una volta usare prima la funzione":	$messaggio = "and/or for once use beforehand the function"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
